## Installation		

### Source Code
- Download [Version 1.5](https://github.com/sepandhaghighi/art/archive/v1.5.zip) or [Latest Source ](https://github.com/sepandhaghighi/art/archive/dev.zip)
- `python3 setup.py install --upgrade` or `python setup.py install --upgrade` (Need root access)				

### PyPI


- Check [Python Packaging User Guide](https://packaging.python.org/installing/)     
- `pip install art --upgrade` or `pip3 install art --upgrade` (Need root access)

### Easy Install

- Run `easy_install --upgrade art` (Need root access)


### Note		

On error, install `requirements` manually :	

- Run `pip install -r requirements.txt` or `pip3 install -r requirements.txt` (Need root access)